"""
forms and functions used for syslogger in NAV
"""

from django import forms
from nav.models.logger import Priority, LoggerCategory, Origin, LogMessageType

DATEFORMAT = ("%Y-%m-%d %H:%M:%S",)

def choice_values(model, field_name):
    """
    Generates a choice_values list to be used with ChoiceField etc.
    :param model: django model
    :param field_name: field to aggregate on
    :return: values_list based on model and field_name
    """
    choice_list = model.objects.values_list(
        field_name).select_related().distinct()
    choices = [(choice[0], choice[0]) for choice in choice_list]
    choices.sort()
    choices.insert(0, ('', u'(All)'))
    return choices


class LoggerGroupSearchForm(forms.Form):
    """LoggerSearchForm"""

    facility = forms.ChoiceField(required=False)
    priority = forms.ChoiceField(required=False)
    mnemonic = forms.ChoiceField(required=False)
    origin = forms.ChoiceField(required=False)
    category = forms.ModelChoiceField(queryset=LoggerCategory.objects.all(),
                                      required=False, empty_label=u'(All)')
    timestamp_from = forms.DateTimeField(input_formats=DATEFORMAT)
    timestamp_to = forms.DateTimeField(input_formats=DATEFORMAT)
    show_log = forms.BooleanField(required=False)

    def __init__(self, *args, **kwargs):
        super(LoggerGroupSearchForm, self).__init__(*args, **kwargs)
        self.fields['facility'].choices = choice_values(LogMessageType,
                                                        'facility')
        self.fields['priority'].choices = choice_values(Priority, 'keyword')
        self.fields['mnemonic'].choices = choice_values(LogMessageType,
                                                        'mnemonic')
        self.fields['origin'].choices = choice_values(Origin, 'name')
